/*
-------------------------------------------------------------------------------
    This file is a part of the VST Preset Generator
    Copyright (C) 2007  Francois Mazen

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-------------------------------------------------------------------------------
  Name: vpgvsthost_test.cpp
  Author: Francois Mazen
  Date: 14/11/13 20:10
  Description: a test class for the VpgVstHost class
-------------------------------------------------------------------------------
*/

#include <QtTest>
#include "../../vpgvsthost.h"

#ifdef WIN64
    #define MOCKPLUGIN_FILENAME "mockplugin_win64.dll"
#elif WIN32
    #define MOCKPLUGIN_FILENAME "mockplugin_win32.dll"
#elif __x86_64
    #define MOCKPLUGIN_FILENAME "libmockplugin_linux.so"
#endif

#define MOCKPLUGIN_ID (CCONST('M', 'C', 'K', '1'))
#define MOCKPLUGIN_NAME "VPG Mock Plugin"

#define STRINGIZE(x) #x
#define STRINGIZE_VALUE_OF(x) STRINGIZE(x)

class VpgVstHostTest : public QObject
{
    Q_OBJECT

private Q_SLOTS:
    void testEmptyHost();
    void loadPlugIn();
};

void VpgVstHostTest::testEmptyHost()
{
    VpgVstHost vpgVstHost;

    QCOMPARE(vpgVstHost.isVstLoaded(), false);
    QVERIFY(vpgVstHost.getLoadedFilename().isEmpty());

    void* chunkPointer = NULL;
    vpgVstHost.getBankChunk(&chunkPointer);
    QCOMPARE(chunkPointer, (void*)NULL);

    QCOMPARE(vpgVstHost.getFxId(), 0);
    QCOMPARE(vpgVstHost.getFxVersion(), 0);
    QCOMPARE(vpgVstHost.getName().isEmpty(), true);
    QCOMPARE(vpgVstHost.getNumberParams(), 0);
    QCOMPARE(vpgVstHost.getNumberPrograms(), 0);

    QCOMPARE(vpgVstHost.getParameterName(1).isEmpty(), true);

    chunkPointer = NULL;
    vpgVstHost.getProgramChunk(&chunkPointer);
    QCOMPARE(chunkPointer, (void*)NULL);

    QCOMPARE(vpgVstHost.useChunk(), false);
}

void VpgVstHostTest::loadPlugIn()
{
    VpgVstHost vpgVstHost;

    QDir mockPluginDir(STRINGIZE_VALUE_OF(MOCKPLUGINS_FOLDER));
    QFileInfo plugInFileInfo(mockPluginDir, MOCKPLUGIN_FILENAME);
    QVERIFY(plugInFileInfo.exists());

    VpgVstHost::ERROR_CODE returnCode = vpgVstHost.load(plugInFileInfo.absoluteFilePath());
    QCOMPARE(returnCode, VpgVstHost::ERROR_NO_ERROR);
    QCOMPARE(vpgVstHost.isVstLoaded(), true);
    QFileInfo loadedFileInfo(vpgVstHost.getLoadedFilename());
    QCOMPARE(loadedFileInfo, plugInFileInfo);

    int32_t fxId = MOCKPLUGIN_ID;
    QCOMPARE(vpgVstHost.getFxId(), fxId);
    QCOMPARE(vpgVstHost.getFxVersion(), 1000);

    QString name = vpgVstHost.getName();
    QCOMPARE(name.isEmpty(), false);
    QCOMPARE(name, QString(MOCKPLUGIN_NAME));

    QCOMPARE(vpgVstHost.getNumberParams(), 3);
    QCOMPARE(vpgVstHost.getNumberPrograms(), 2);

    for(int32_t paramIndex = 0; paramIndex < 3; paramIndex++)
    {
        QString parameterName = vpgVstHost.getParameterName(paramIndex);
        QCOMPARE(parameterName.isEmpty(), false);
        QString paramName("Param");
        paramName.append(QString::number(paramIndex + 1));
        QCOMPARE(parameterName, paramName);
    }

    void* chunkPointer = NULL;
    vpgVstHost.getProgramChunk(&chunkPointer);
    QCOMPARE(chunkPointer, (void*)NULL);

    chunkPointer = NULL;
    vpgVstHost.getBankChunk(&chunkPointer);
    QCOMPARE(chunkPointer, (void*)NULL);

    QCOMPARE(vpgVstHost.useChunk(), false);

    vpgVstHost.close();
    QCOMPARE(vpgVstHost.isVstLoaded(), false);
}

QTEST_GUILESS_MAIN(VpgVstHostTest)

#include "vpgvsthost_test.moc"
