############################################################################
#    This file is a part of the VST Preset Generator
#    Copyright (C) 2007-2016  Francois Mazen
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License along
#    with this program; if not, write to the Free Software Foundation, Inc.,
#    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
############################################################################


TEMPLATE = app

# Target name
!contains(QMAKE_HOST.arch, x86_64) {
    message("arch: 32 bits")
    TARGET = vpg32
} else {
    message("arch: 64 bits")
    TARGET = vpg64
}
linux*:TARGET = vpg

# Version
VPG_MAJOR_NUMBER=0
VPG_MINOR_NUMBER=2
VPG_REVISION_NUMBER=8

VERSION=$${VPG_MAJOR_NUMBER}.$${VPG_MINOR_NUMBER}.$${VPG_REVISION_NUMBER}
DEFINES+= VPG_MAJOR_NUMBER=$$VPG_MAJOR_NUMBER
DEFINES+= VPG_MINOR_NUMBER=$$VPG_MINOR_NUMBER
DEFINES+= VPG_REVISION_NUMBER=$$VPG_REVISION_NUMBER
message(VPG version: $$VERSION)

# Windows dll informations
QMAKE_TARGET_PRODUCT="VST Preset Generator"
QMAKE_TARGET_COMPANY="VST Preset Generator"
QMAKE_TARGET_DESCRIPTION="Random Preset Generator for VST Plugins"
QMAKE_TARGET_COPYRIGHT="Copyright 2007-2016 Francois Mazen"

DEPENDPATH += . \
    translations
INCLUDEPATH += .

# VST SDK
exists(./vst2.x/aeffectx.h) {
    message("using VST SDK")
    HEADERS += vst2.x/aeffect.h \
               vst2.x/aeffectx.h \
               vst2.x/vstfxstore.h
} else {
    warning("VST SDK not found, using VeSTige header as substitute")
    HEADERS += vestige/aeffectx.h \
               vestige/vestige.h
    DEFINES += USE_VESTIGE
}

# Input
HEADERS += filetypedialog.h \
    fxheader.h \
    maindialog.h \
    parametertablemodel.h \
    parameter.h \
    paramvaluedelegate.h \
    randommodedelegate.h \
    vpglanguagechooser.h \
    vpgrandom.h \
    vpgvsthost.h \
    vstlistmodel.h \
    vpgversion.h \
    endiannessconverter.h \
    vpgfile.h \
    vstpreset.h \
    vpgsettings.h

SOURCES += filetypedialog.cpp \
    fxheader.cpp \
    main.cpp \
    maindialog.cpp \
    parametertablemodel.cpp \
    parameter.cpp \
    paramvaluedelegate.cpp \
    randommodedelegate.cpp \
    vpglanguagechooser.cpp \
    vpgrandom.cpp \
    vpgvsthost.cpp \
    vstlistmodel.cpp \
    vpgversion.cpp \
    endiannessconverter.cpp \
    vpgfile.cpp \
    vstpreset.cpp \
    vpgsettings.cpp

DISTFILES += vpg_linux_deploy.pri

RESOURCES += vpg.qrc
TRANSLATIONS += translations/vpg_en.ts \
    translations/vpg_fr.ts
QT += xml \
    widgets

RC_ICONS="vpg.ico"

# Disable symbol __cdecl for linux platform because of issue in VST SDK.
linux*:QMAKE_CXXFLAGS += -D__cdecl=\"\"

QMAKE_LFLAGS += -static-libgcc

# Deploy on Linux:
include(vpg_linux_deploy.pri)

